@@ -1,7 +1,7 @@
 /*
  *  MidiController.h
  *
- *  Copyright (c) 2001-2012 Nick Dowell
+ *  Copyright (c) 2001-2016 Nick Dowell
  *
  *  This file is part of amsynth.
  *
@@ -25,14 +25,13 @@
 #include "PresetController.h"
 #include "Parameter.h"
 #include "Thread.h"
+#include "types.h"
 
 
 #define MAX_CC 128
 
 typedef unsigned char uchar;
 
-class MidiDriver;
-
 class MidiEventHandler
 {
 public:
@@ -52,7 +51,6 @@ class MidiController
 {
 public:
 	MidiController();
-	virtual ~MidiController();
 
 	void	setPresetController	(PresetController & pc) { presetController = &pc; }
 	void	SetMidiEventHandler(MidiEventHandler* h) { _handler = h; }
@@ -61,21 +59,16 @@ public:
 
 	void	clearControllerMap();
 	void	loadControllerMap();
-	void	saveControllerMap();
 
-	int		getControllerForParameter(int paramId);
-	void	setControllerForParameter(int paramId, int cc);
+	int		getControllerForParameter(Param paramId);
+	void	setControllerForParameter(Param paramId, int cc);
 
 	Parameter & getLastControllerParam() { return last_active_controller; };
 
 	int		get_midi_channel	() { return channel; }
 	void	set_midi_channel	( int ch );
-	
-	void	setMidiDriver		(MidiDriver *driver) { _midiDriver = driver; }
-	int     sendMidi_values		();
-	void	send_changes		(bool force=false);
 
-	void	timer_callback		();
+	void 	generateMidiOutput	(std::vector<amsynth_midi_cc_t> &);
 
 private:
 	void dispatch_note(unsigned char ch,
@@ -83,17 +76,16 @@ private:
     void controller_change(unsigned char controller, unsigned char value);
     void pitch_wheel_change(float val);
 
+    void saveControllerMap();
+
     PresetController *presetController;
     unsigned char status, data, channel;
 	Parameter last_active_controller;
 	unsigned char _midi_cc_vals[MAX_CC];
 	MidiEventHandler* _handler;
-	MidiDriver *_midiDriver;
 	unsigned char _rpn_msb, _rpn_lsb;
 
 	int _cc_to_param_map[MAX_CC];
 	int _param_to_cc_map[kAmsynthParameterCount];
-
-	bool _config_needs_save;
 };
 #endif
